import { Injectable } from '@angular/core';

@Injectable({
  providedIn: 'root'
})
export class ViewerService {

  // tslint:disable-next-line: variable-name
  private _viewer;
  private measureHandler;

  constructor() {
    console.log('%c viewer service constructed! ', 'background-color: red; color: white; padding: 5px');
    this.handleMeasure = this.handleMeasure.bind(this);
  }

  get viewer() {
    return this._viewer;
  }

  initViewer(container: string | Element, options?: object): object {
    if (!this._viewer) {
      this._viewer = new smart3d.Viewer(container, options || {});
    }
    return this._viewer;
  }

  handleMeasure(measureMode: number, options?: {
    isGround: boolean;
    showLabel: boolean;
  }) {
    if (
      measureMode !== smart3d.MeasureMode.Distance &&
      measureMode !== smart3d.MeasureMode.Angle &&
      measureMode !== smart3d.MeasureMode.Area &&
      measureMode !== smart3d.MeasureMode.DVH
    ) {
      throw new Cesium.DeveloperError('measure mode must be one of smart3d.MeasureMode');
    }

    if (this._viewer) {
      this.measureHandler = new smart3d.MeasureHandler(this.viewer, measureMode, options && options);
      this.measureHandler.activate();
    }
  }
}
